#
# spec file for package systemd-presets-branding-SLE-SAP
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define generic_name systemd-presets-branding

Name:           %{generic_name}-SLE-SAP
VCS: https://src.suse.de/SLFO-pool/systemd-presets-branding-SLE-SAP#5ca21431216345010e0bcc75d0acb0f18458a48b62e53be6502e64645e84d337
Version:        16.0
Release:        160000.4.2
Summary:        Systemd default presets for SUSE Linux Enterprise Server for SAP Applications
License:        ISC
Group:          System/Base
Source1:        default-SAP.preset
BuildRequires:  systemd
#!BuildIgnore:  systemd-presets-branding
# FIXME: use proper Requires(pre/post/preun/...)
# For the stuff that the systemd_preset_pre macro does.
BuildRequires:  systemd-presets-common-SUSE
Requires(pre):  systemd-presets-common-SUSE
Requires:       systemd-presets-branding-SLE
PreReq:         coreutils
Supplements:    packageand(systemd:branding-SLE-SAP)
BuildArch:      noarch

Requires(post): bash
Requires(pre):  bash

%description
Default presets for systemd on SUSE Linux Enterprise Server for SAP Applications.

%prep
%setup -q -T -c

%build

%install
mkdir -p %{buildroot}%{_prefix}/lib/%{generic_name}
mkdir -p %{buildroot}%{_prefix}/lib/systemd/system-preset
# everything that must be enabled only in SLES4SAP
install -m644 %{SOURCE1}  %{buildroot}%{_prefix}/lib/systemd/system-preset/96-default-SAP.preset


%pre
# On initial installation, branding-preset-states does not yet exist,
# which is why we also check for the file to be present/executable
if [ $1 -gt 1 -a -x %{_prefix}/lib/%{generic_name}/branding-preset-states ] ; then
        #
        # Save the old state so we can detect which package have its
        # default changed later.
        #
        # Note: the old version of the script is used here.
        #
        %{_prefix}/lib/%{generic_name}/branding-preset-states save
elif [ $1 -eq 1 ]; then
  touch /run/rpm-%{name}-preset-all
fi

%post
if [ $1 -gt 1 -a -x %{_prefix}/lib/%{generic_name}/branding-preset-states ] ; then
        #
        # Now that the updated presets are installed, find the ones
        # that have been changed and apply "systemct preset" on them.
        #
        %{_prefix}/lib/%{generic_name}/branding-preset-states apply-changes
fi

%posttrans
if [ -f /run/rpm-%{name}-preset-all ]; then
  # Enable all services, which were installed before systemd
  # Don't disable services, since this would disable the
  # complete network stack.
  systemctl preset-all --preset-mode=enable-only
fi
rm -f /run/rpm-%{name}-preset-all

%files
%dir %{_prefix}/lib/systemd
%dir %{_prefix}/lib/systemd/system-preset/
%{_prefix}/lib/systemd/system-preset/96-default-SAP.preset

%changelog
* Fri Mar 14 2025 abriel@suse.com
- because of the dependency on systemd-presets-branding-SLE added
  last time remove the left over provides and conflicts:
  'Provides: %%{generic_name} = %%{version}' and
  'Conflicts: otherproviders(%%{generic_name})'
* Wed Mar  5 2025 abriel@suse.com
- add 'Requires: systemd-presets-branding-SLE' to get the SLES
  default presets for SAP workloads too.
  (bsc#1237923)
* Mon Jan 20 2025 abriel@suse.com
- update preset package for (jsc#PED-10072):
  * enable saptune.service as it is the replacement for sapconf
    and sapconf was enabled by default in SLES 15
* Thu Dec  5 2024 abriel@suse.com
- Initial package for SAP related presets of systemd services
  * enable sysctl-logger.service
  * enable sysstat.service
  * enable uuidd.socket
  (jsc#PED-10072)
